spannertools.iterate_components_forward_in_spanner
==================================================

.. autofunction:: abjad.tools.spannertools.iterate_components_forward_in_spanner.iterate_components_forward_in_spanner
